Module: xenomai-2.6
Branch: master
Commit: 5e5b405567d4af959781cdfc31e7f46bd416c08f
URL:    
http://git.xenomai.org/?p=xenomai-2.6.git;a=commit;h=5e5b405567d4af959781cdfc31e7f46bd416c08f

Author: Paul Corner <pau...@tuxcnc.org>
Date:   Sun Feb  2 22:58:23 2014 +0000

Trivial spelling correction for the word 'implicitly'

---

 examples/rtdm/profiles/serial/cross-link.c |    2 +-
 include/asm-x86/fptest.h                   |    2 +-
 ksrc/skins/native/heap.c                   |    4 ++--
 ksrc/skins/native/mutex.c                  |    4 ++--
 ksrc/skins/native/queue.c                  |    2 +-
 ksrc/skins/native/task.c                   |    6 +++---
 6 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/examples/rtdm/profiles/serial/cross-link.c 
b/examples/rtdm/profiles/serial/cross-link.c
index a715cf5..110a8df 100644
--- a/examples/rtdm/profiles/serial/cross-link.c
+++ b/examples/rtdm/profiles/serial/cross-link.c
@@ -70,7 +70,7 @@ static const struct rtser_config write_config = {
        .config_mask       = RTSER_SET_BAUD | RTSER_SET_TIMESTAMP_HISTORY,
        .baud_rate         = 115200,
        .timestamp_history = RTSER_DEF_TIMESTAMP_HISTORY,
-       /* the rest implicitely remains default */
+       /* the rest implicitly remains default */
 };
 
 static int close_file( int fd, char *name)
diff --git a/include/asm-x86/fptest.h b/include/asm-x86/fptest.h
index 61f5c19..070a683 100644
--- a/include/asm-x86/fptest.h
+++ b/include/asm-x86/fptest.h
@@ -59,7 +59,7 @@ static inline int fp_linux_begin(void)
 #endif /* 3DNow or RAID 456 */
        kernel_fpu_begin();
        /* kernel_fpu_begin() does no re-initialize the fpu context, but
-          fp_regs_set() implicitely expects an initialized fpu context, so
+          fp_regs_set() implicitly expects an initialized fpu context, so
           initialize it here. */
        __asm__ __volatile__("fninit");
        return 0;
diff --git a/ksrc/skins/native/mutex.c b/ksrc/skins/native/mutex.c
index 9ee40f5..9365cbe 100644
--- a/ksrc/skins/native/mutex.c
+++ b/ksrc/skins/native/mutex.c
@@ -421,7 +421,7 @@ int rt_mutex_acquire_inner(RT_MUTEX *mutex, RTIME timeout,
  * Attempt to lock a mutex. The calling task is blocked until the
  * mutex is available, in which case it is locked again before this
  * service returns. Mutexes have an ownership property, which means
- * that their current owner is tracked. Xenomai mutexes are implicitely
+ * that their current owner is tracked. Xenomai mutexes are implicitly
  * recursive and implement the priority inheritance protocol.
  *
  * Since a nested locking count is maintained for the current owner,
@@ -490,7 +490,7 @@ int rt_mutex_acquire(RT_MUTEX *mutex, RTIME timeout)
  * Attempt to lock a mutex. The calling task is blocked until the
  * mutex is available, in which case it is locked again before this
  * service returns. Mutexes have an ownership property, which means
- * that their current owner is tracked. Xenomai mutexes are implicitely
+ * that their current owner is tracked. Xenomai mutexes are implicitly
  * recursive and implement the priority inheritance protocol.
  *
  * Since a nested locking count is maintained for the current owner,
diff --git a/ksrc/skins/native/queue.c b/ksrc/skins/native/queue.c
index 2d0d47f..9de8c72 100644
--- a/ksrc/skins/native/queue.c
+++ b/ksrc/skins/native/queue.c
@@ -208,7 +208,7 @@ static void __queue_flush_private(xnheap_t *heap,
  *
  * - Q_SHARED causes the queue to be sharable between kernel and
  * user-space tasks. Otherwise, the new queue is only available for
- * kernel-based usage. This flag is implicitely set when the caller is
+ * kernel-based usage. This flag is implicitly set when the caller is
  * running in user-space. This feature requires the real-time support
  * in user-space to be configured in (CONFIG_XENO_OPT_PERVASIVE).
  *
diff --git a/ksrc/skins/native/heap.c b/ksrc/skins/native/heap.c
index 61f6676..bd7d93b 100644
--- a/ksrc/skins/native/heap.c
+++ b/ksrc/skins/native/heap.c
@@ -225,7 +225,7 @@ static void __heap_flush_private(xnheap_t *heap,
  *
  * - H_MAPPABLE causes the heap to be sharable between kernel and
  * user-space contexts. Otherwise, the new heap is only available for
  * kernel-based usage. This flag is implicitely set when the caller is
  * running in user-space. This feature requires the real-time support
  * in user-space to be configured in (CONFIG_XENO_OPT_PERVASIVE).
  *
@@ -577,7 +577,7 @@ int rt_heap_alloc(RT_HEAP *heap, size_t size, RTIME 
timeout, void **blockp)
 
                if (!block) {
                        /* It's ok to pass zero for size here, since the 
requested
-                          size is implicitely the whole heap space; but if
+                          size is implicitly the whole heap space; but if
                           non-zero is given, it must match the original heap
                           size. */
 
@@ -225,7 +225,7 @@ static void __heap_flush_private(xnheap_t *heap,
  * - H_MAPPABLE causes the heap to be sharable between kernel and
  * user-space contexts. Otherwise, the new heap is only available for
- * kernel-based usage. This flag is implicitely set when the caller is
+ * kernel-based usage. This flag is implicitly set when the caller is
  * running in user-space. This feature requires the real-time support
  * in user-space to be configured in (CONFIG_XENO_OPT_PERVASIVE).
diff --git a/ksrc/skins/native/task.c b/ksrc/skins/native/task.c
index 18e1eb8..2d31f41 100644
--- a/ksrc/skins/native/task.c
+++ b/ksrc/skins/native/task.c
@@ -979,7 +979,7 @@ int rt_task_sleep(RTIME delay)
                return -EWOULDBLOCK;
 
        /* Calling the suspension service on behalf of the current task
-          implicitely calls the rescheduling procedure. */
+          implicitly calls the rescheduling procedure. */
 
        xnpod_suspend_thread(self, XNDELAY, delay, XN_RELATIVE, NULL);
 
@@ -1053,7 +1053,7 @@ int rt_task_sleep_until(RTIME date)
 
        /*
         * Calling the suspension service on behalf of the current
         * task implicitely calls the rescheduling procedure.
         */
        xnpod_suspend_thread(self, XNDELAY, date, mode, NULL);
 
@@ -1311,7 +1311,7 @@ int rt_task_remove_hook(int type, void (*routine) (void 
*cookie))
  * rt_task_notify(). A task can block the signal delivery by passing
  * the T_NOSIG bit to rt_task_set_mode().
  *
  * Calling this service implicitely unblocks the signal delivery for
  * the caller.
  *
  * @param handler The address of the user-supplied routine to fire
@@ -1053,7 +1053,7 @@ int rt_task_sleep_until(RTIME date)
        /*
         * Calling the suspension service on behalf of the current
-        * task implicitely calls the rescheduling procedure.
+        * task implicitly calls the rescheduling procedure.
         */
        xnpod_suspend_thread(self, XNDELAY, date, mode, NULL);
@@ -1311,7 +1311,7 @@ int rt_task_remove_hook(int type, void (*routine) (void 
  * the T_NOSIG bit to rt_task_set_mode().
  *
- * Calling this service implicitely unblocks the signal delivery for
+ * Calling this service implicitly unblocks the signal delivery for
  * the caller.
  *


_______________________________________________
Xenomai-git mailing list
Xenomai-git@xenomai.org
http://www.xenomai.org/mailman/listinfo/xenomai-git

Reply via email to